@@ -111,7 +111,10 @@ def log(*msg, level=logging.INFO, writter=None):
             logging.info(finalmsg)
 
     else :
-        print(msg, file=writter)
+        finalmsg = ""
+        for item in msg :
+            finalmsg += str(item)
+        print(finalmsg, file=writter)
 
 def get_from_vars_or_args_or_environment(arg_pos, variable_name, vars, args):
     """Gets the argument from the position specified or gets the value from the table vars or gets the environment variable name passed.
@@ -293,8 +296,7 @@ def log_on(user=None, password=None, account=None, database=None, warehouse=None
             }
         )
     except Exception as e:
-        print(e)
-        log(colored('*** Failure: logon failed :', 'red') + str(e), level = logging.ERROR, writter = sys.stderr)
+        log(f"{colored('*** Failure: logon failed :', 'red')} { str(e) }", level = logging.ERROR, writter = sys.stderr)
         error_code = 333
         quit_application(error_code)
     if c:
@@ -375,11 +377,11 @@ def exec(sql_string, using=None, con=None):
     cur = con.cursor()
     try:
         error_code = 0
-        log(colored("Executing: ") + colored(sql_string, 'cyan'))
+        log(f"{colored('Executing: ')} { colored(sql_string, 'cyan') }")
         if ("$" in sql_string or "&" in sql_string):
             log ("Expanding variables in SQL statement")
             sql_string = expandvars(sql_string, passed_variables)
-            log (colored("Expanded string: ") + colored(sql_string, 'green'))
+            log (f"{colored('Expanded string: ')} {colored(sql_string, 'green')}")
         if (using is not None):
                 #we need to change variables from {var} to %(format)
                 sql_string = re.sub(r'\{([^}]*)\}', r'%(\1)', sql_string)
@@ -457,7 +459,7 @@ def _handle_syntax_error(e, sql_string):
                 column = int(match.groups()[1])
                 if line != last_line:
                     error_line = sql_lines[line]
-                    error_line = error_line[:column] + colored(error_line[column:], 'red')
+                    error_line = f"{error_line[:column]} {colored(error_line[column:], 'red')}"
                     error_fragment = error_fragment + f"{line:0>2d},{column:0>2d}:{error_line}\n"
                 last_line = line
         log(error_fragment, level = logging.ERROR)
@@ -467,7 +469,7 @@ def _handle_sql_error(e):
     global error_code, error_level
     error_code = e.errno
     if error_code not in _severities_dictionary or _severities_dictionary[error_code] != 0:
-        msg = colored("*** Failure " + str(e), 'red')
+        msg = colored(f"*** Failure {str(e)}", 'red')
         log(msg, level = logging.ERROR, writter = sys.stderr)
         if error_code in _severities_dictionary:
             error_level = max(error_level, _severities_dictionary[error_code])
